@@ -8,15 +8,15 @@ from django.db import migrations, models
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('admin_interface', '0012_update_verbose_names'),
+        ("admin_interface", "0012_update_verbose_names"),
     ]
 
     operations = [
         migrations.AddField(
-            model_name='theme',
-            name='related_modal_close_button_visible',
+            model_name="theme",
+            name="related_modal_close_button_visible",
             field=models.BooleanField(
-                default=True,
-                verbose_name='close button visible'),
+                default=True, verbose_name="close button visible"
+            ),
         ),
     ]
